@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::Author::PERLANCAR;
 
-our $DATE = '2016-02-20'; # DATE
-our $VERSION = '0.47'; # VERSION
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '0.48'; # VERSION
 
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -19,7 +19,7 @@ sub configure {
     $self->add_plugins(
         'Rinci::AbstractFromMeta',
         'PodnameFromFilename',
-        'PERLANCAR::CheckDepDists',
+        #'PERLANCAR::CheckDepDists', # 2016-03-16 disabled because it slows down building process, i'll do this occasionally later
         'PERLANCAR::EnsurePrereqToSpec',
         'PERLANCAR::MetaResources',
         'CheckChangeLog',
@@ -63,7 +63,7 @@ Dist::Zilla::PluginBundle::Author::PERLANCAR - Dist::Zilla like PERLANCAR when y
 
 =head1 VERSION
 
-This document describes version 0.47 of Dist::Zilla::PluginBundle::Author::PERLANCAR (from Perl distribution Dist-Zilla-PluginBundle-Author-PERLANCAR), released on 2016-02-20.
+This document describes version 0.48 of Dist::Zilla::PluginBundle::Author::PERLANCAR (from Perl distribution Dist-Zilla-PluginBundle-Author-PERLANCAR), released on 2016-03-16.
 
 =head1 SYNOPSIS
 
